#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 modern-uri
version:              0.3.4.1
visibility:           public
id:                   modern-uri-0.3.4.1-v472keFKueHixOvPxm7G0
key:                  modern-uri-0.3.4.1-v472keFKueHixOvPxm7G0
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  4fe374e8da83a3360e72a43b982fbfd8
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-8.10.5/site-local/modern-uri-0.3.4.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/modern-uri-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/modern-uri-0.3.4.1
hs-libraries:         HSmodern-uri-0.3.4.1-v472keFKueHixOvPxm7G0
depends:
    QuickCheck-2.14.2-AlBcjlnVb6HBYuJ8lOviFD base-4.14.2.0
    bytestring-0.10.12.0 containers-0.6.4.1
    contravariant-1.5.3-KWoYE9wiUjmElzHNq2wj10 deepseq-1.4.4.0
    exceptions-0.10.4 megaparsec-9.0.1-CgNxKp13Re58VqY3iga6b3 mtl-2.2.2
    profunctors-5.6.2-68Okl6PP0cYKcJgfa1by0Q
    reflection-2.1.6-FR239ENUILqLfyqzHK1WBr
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV template-haskell-2.16.0.0
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

